@@ -261,17 +261,19 @@ def has_words(qs, article):
 			return False
 	return True
 
-def prepare_articles(articles):
+def prepare_articles(articles, escape=True):
 	"""Escape HTML tags, etc."""
 	
 	new_articles = []
 	
 	for article in articles:
-		article[0]['title'] = article[0]['title'].replace('&', '&amp;')
-		article[0]['title'] = article[0]['title'].replace('<', '&lt;')
-		article[0]['title'] = article[0]['title'].replace('>', '&gt;')
-		article[0]['title'] = article[0]['title'].replace('"', '&quot;')
+		if escape:
+			article[0]['title'] = article[0]['title'].replace('&', '&amp;')
+			article[0]['title'] = article[0]['title'].replace('<', '&lt;')
+			article[0]['title'] = article[0]['title'].replace('>', '&gt;')
+			article[0]['title'] = article[0]['title'].replace('"', '&quot;')
 		article[0]['link'] = urlencode({'': article[0]['link']})[1:]
+		article[0]['summary'] = article[0]['summary'].replace('\n', '<br/>')
 		new_articles.append(article)
 	
 	return new_articles
@@ -300,16 +302,20 @@ def article_list(page_number=1):
 		qs = q.split()
 		articles = filter(lambda x: has_words(qs, x), articles)
 	
+	articles = prepare_articles(articles, False)
+	all_articles = articles
 	articles = split_into_pages(articles, 30)
 	try:
-		requested_page = prepare_articles(articles[page_number-1])
+		requested_page = articles[page_number-1]
 	except IndexError:
 		requested_page = []
 	
+	
 	return main_page.render(articles=requested_page,
 		num_pages=len(articles),
 		page_num=page_number,
-		q=q)
+		q=q,
+		all_articles=all_articles)
 
 class ParserDaemon(Daemon):
 	def __init__(self):
@@ -321,7 +327,7 @@ class ParserDaemon(Daemon):
 		if os.stat(se.name).st_size > 102400:
 			se.truncate()
 		
-		super(ParserDaemon, self).__init__(pidfile, True, stdout=so, stderr=se)
+		super(ParserDaemon, self).__init__(pidfile, stdout=so, stderr=se)
 	
 	def onStart(self):
 		t1 = Thread(target=dump_articles_per, args=(config.update_interval,))
